@@ -16,7 +16,7 @@ class Entity(Base, SerializerMixin):
     date_created  = Column(DateTime,  default=datetime.datetime.utcnow)
     date_modified = Column(DateTime,  default=datetime.datetime.utcnow,onupdate=datetime.datetime.utcnow)    
 
-    name = Column(String(200), nullable=True)
+    name = Column(Text(), nullable=True)
     description = Column(Text(), nullable=True)
     is_instance_of = ""
 
